@@ -61,13 +61,12 @@ class Node(metaclass=abc.ABCMeta):
 
         if self.conf.nats.sub_conf and self.conf.nats.sub_conf.subject:
             logger.debug("sub>>>")
-            config = api.ConsumerConfig(**self.conf.nats.sub_conf.config)
             osub = await self.js.subscribe(
                 self.conf.nats.sub_conf.subject,
                 queue=self.conf.nats.sub_conf.queue,
                 durable=self.conf.nats.sub_conf.durable,
                 stream=self.conf.nats.sub_conf.stream,
-                config=config,
+                config=self.conf.nats.sub_conf.config,
                 manual_ack=self.conf.nats.sub_conf.manual_ack,
                 ordered_consumer=self.conf.nats.sub_conf.ordered_consumer,
                 idle_heartbeat=self.conf.nats.sub_conf.idle_heartbeat,
